@@ -29,15 +29,15 @@ copy_and_rename() {
     find "$src_dir" -maxdepth 1 -type f -exec cp {} "$dest_dir/" \;
 
     # Rename files in the destination directory
-    for file in "$dest_dir"/*_en; do
-        mv "$file" "${file%_en}_$LANG_CODE"
+    for file in "$dest_dir"/*_en_US; do
+        mv "$file" "${file%_en_US}_$LANG_CODE"
     done
 }
 
 # Copy and rename in hints, info, and list_of_shortcuts
-copy_and_rename "txts/hints/en" "txts/hints/$LANG_CODE"
-copy_and_rename "txts/info/en" "txts/info/$LANG_CODE"
-cp "txts/list_of_shortcuts/en" "txts/list_of_shortcuts/$LANG_CODE"
+copy_and_rename "txts/hints/en_US" "txts/hints/$LANG_CODE"
+copy_and_rename "txts/info/en_US" "txts/info/$LANG_CODE"
+cp "txts/list_of_shortcuts/en_US" "txts/list_of_shortcuts/$LANG_CODE"
 
 echo "Processing completed for language code: $LANG_CODE"
 
