@@ -796,11 +796,15 @@ static gboolean avoid_overlapping (G_GNUC_UNUSED gpointer user_data)
 
 void set_entry_fields (void)
 {
+    const gchar *right_to_left = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) ? "&#8207;" : "";
+
     gtk_widget_show (ks.entry_grid);
 
     // Default settings
     gtk_label_set_text (GTK_LABEL (ks.entry_labels[MENU_ELEMENT_OR_VALUE_ENTRY]), _(" Label: "));
-    gtk_label_set_text (GTK_LABEL (ks.entry_labels[EXECUTE_ENTRY]), " Execute: ");
+
+    g_autofree gchar *execute_label_text = g_strdup_printf  ("%s Execute: ", right_to_left);
+    gtk_label_set_markup (GTK_LABEL (ks.entry_labels[EXECUTE_ENTRY]), execute_label_text);
     gtk_widget_set_sensitive (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY], TRUE);
     gtk_widget_hide (ks.icon_chooser);
     gtk_widget_hide (ks.remove_icon);
@@ -855,12 +859,18 @@ void set_entry_fields (void)
     }
     // Option other than "startupnotify" and "enabled".
     else {
-        g_autofree gchar *label_txt = g_strdup_printf (" %s: ", 
-                                                       (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "wmclass")) ? 
-                                                       "WM_CLASS" : ks.txt_fields[MENU_ELEMENT_TXT]);
-        label_txt[1] = g_ascii_toupper (label_txt[1]);
+        g_autofree gchar *label_txt = NULL;
 
-        gtk_label_set_text (GTK_LABEL (ks.entry_labels[MENU_ELEMENT_OR_VALUE_ENTRY]), label_txt);
+        if (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "wmclass")) {
+            label_txt = g_strdup_printf ("%s WM_CLASS: ", right_to_left);
+        }
+        else {
+            g_autofree gchar *capitalized_field_name = g_strdup (ks.txt_fields[MENU_ELEMENT_TXT]);
+            capitalized_field_name[0] = g_ascii_toupper (capitalized_field_name[0]);
+            label_txt = g_strdup_printf ("%s %s: ", right_to_left, capitalized_field_name);
+        }
+
+        gtk_label_set_markup (GTK_LABEL (ks.entry_labels[MENU_ELEMENT_OR_VALUE_ENTRY]), label_txt);
         if (NOT_NULL_AND_NOT_EMPTY (ks.txt_fields[VALUE_TXT])) {
             gtk_entry_set_text (GTK_ENTRY (ks.entry_fields[MENU_ELEMENT_OR_VALUE_ENTRY]), ks.txt_fields[VALUE_TXT]);
         }
